@@ -32,6 +32,24 @@ function _aws_cdk_aws_s3outposts_CfnBucket(p) {
 }
 function _aws_cdk_aws_s3outposts_CfnBucket_AbortIncompleteMultipartUploadProperty(p) {
 }
+function _aws_cdk_aws_s3outposts_CfnBucket_FilterProperty(p) {
+}
+function _aws_cdk_aws_s3outposts_CfnBucket_FilterAndOperatorProperty(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    try {
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    _aws_cdk_aws_s3outposts_CfnBucket_FilterTagProperty(o);
+    }
+    finally {
+        visitedObjects.delete(p);
+    }
+}
+function _aws_cdk_aws_s3outposts_CfnBucket_FilterTagProperty(p) {
+}
 function _aws_cdk_aws_s3outposts_CfnBucket_LifecycleConfigurationProperty(p) {
 }
 function _aws_cdk_aws_s3outposts_CfnBucket_RuleProperty(p) {
@@ -82,4 +100,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_s3outposts_CfnAccessPointProps, _aws_cdk_aws_s3outposts_CfnAccessPoint, _aws_cdk_aws_s3outposts_CfnAccessPoint_VpcConfigurationProperty, _aws_cdk_aws_s3outposts_CfnBucketProps, _aws_cdk_aws_s3outposts_CfnBucket, _aws_cdk_aws_s3outposts_CfnBucket_AbortIncompleteMultipartUploadProperty, _aws_cdk_aws_s3outposts_CfnBucket_LifecycleConfigurationProperty, _aws_cdk_aws_s3outposts_CfnBucket_RuleProperty, _aws_cdk_aws_s3outposts_CfnBucketPolicyProps, _aws_cdk_aws_s3outposts_CfnBucketPolicy, _aws_cdk_aws_s3outposts_CfnEndpointProps, _aws_cdk_aws_s3outposts_CfnEndpoint, _aws_cdk_aws_s3outposts_CfnEndpoint_NetworkInterfaceProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_s3outposts_CfnAccessPointProps, _aws_cdk_aws_s3outposts_CfnAccessPoint, _aws_cdk_aws_s3outposts_CfnAccessPoint_VpcConfigurationProperty, _aws_cdk_aws_s3outposts_CfnBucketProps, _aws_cdk_aws_s3outposts_CfnBucket, _aws_cdk_aws_s3outposts_CfnBucket_AbortIncompleteMultipartUploadProperty, _aws_cdk_aws_s3outposts_CfnBucket_FilterProperty, _aws_cdk_aws_s3outposts_CfnBucket_FilterAndOperatorProperty, _aws_cdk_aws_s3outposts_CfnBucket_FilterTagProperty, _aws_cdk_aws_s3outposts_CfnBucket_LifecycleConfigurationProperty, _aws_cdk_aws_s3outposts_CfnBucket_RuleProperty, _aws_cdk_aws_s3outposts_CfnBucketPolicyProps, _aws_cdk_aws_s3outposts_CfnBucketPolicy, _aws_cdk_aws_s3outposts_CfnEndpointProps, _aws_cdk_aws_s3outposts_CfnEndpoint, _aws_cdk_aws_s3outposts_CfnEndpoint_NetworkInterfaceProperty };
